@@ -187,10 +187,10 @@ impl VegaFusionTable {
                 }
             }
         } else {
-            return Err(VegaFusionError::internal(&format!(
+            Err(VegaFusionError::internal(&format!(
                 "Expected JSON array, not: {}",
                 value
-            )));
+            )))
         }
     }
 
