@@ -6,8 +6,11 @@
  * Please consult the license documentation provided alongside
  * this program the details of the active license.
  */
+use crate::task_graph::timezone::RuntimeTzConfig;
 use async_trait::async_trait;
+use std::collections::HashMap;
 use std::convert::TryInto;
+use vegafusion_core::data::dataset::VegaFusionDataset;
 use vegafusion_core::error::Result;
 use vegafusion_core::proto::gen::tasks::task::TaskKind;
 use vegafusion_core::proto::gen::tasks::Task;
@@ -18,7 +21,8 @@ pub trait TaskCall {
     async fn eval(
         &self,
         values: &[TaskValue],
-        local_tz: &Option<chrono_tz::Tz>,
+        tz_config: &Option<RuntimeTzConfig>,
+        inline_datasets: HashMap<String, VegaFusionDataset>,
     ) -> Result<(TaskValue, Vec<TaskValue>)>;
 }
 
@@ -27,14 +31,15 @@ impl TaskCall for Task {
     async fn eval(
         &self,
         values: &[TaskValue],
-        local_tz: &Option<chrono_tz::Tz>,
+        tz_config: &Option<RuntimeTzConfig>,
+        inline_datasets: HashMap<String, VegaFusionDataset>,
     ) -> Result<(TaskValue, Vec<TaskValue>)> {
         match self.task_kind() {
             TaskKind::Value(value) => Ok((value.try_into()?, Default::default())),
-            TaskKind::DataUrl(task) => task.eval(values, local_tz).await,
-            TaskKind::DataValues(task) => task.eval(values, local_tz).await,
-            TaskKind::DataSource(task) => task.eval(values, local_tz).await,
-            TaskKind::Signal(task) => task.eval(values, local_tz).await,
+            TaskKind::DataUrl(task) => task.eval(values, tz_config, inline_datasets).await,
+            TaskKind::DataValues(task) => task.eval(values, tz_config, inline_datasets).await,
+            TaskKind::DataSource(task) => task.eval(values, tz_config, inline_datasets).await,
+            TaskKind::Signal(task) => task.eval(values, tz_config, inline_datasets).await,
         }
     }
 }
